==> ejc-sdbjmaterial-impl-3.0.0-20201012.122236-2-sources.jar: com/ejianc/integration/sdbjmaterial/vo/OutstoreDetailVO.java <==
package com.ejianc.integration.sdbjmaterial.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 领料出库子表
 * 
 * @author generator
 * 
 */
public class OutstoreDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String materialName; // 物资名称
    private Long materialId; // 物资id
    private String model; // 规格型号
    private String unit; // 单位
    private java.math.BigDecimal price; // 单价/租赁单价
    private java.math.BigDecimal outNum; // 申请数量/出库数量
    private java.math.BigDecimal amount; // 金额
    private java.math.BigDecimal adjustNum; // 调差额
    private String useFor; // 用途
    private java.math.BigDecimal nowStoreAmount; // 当前库存金额
    private String memo; // 备注
    private Long pid; // 主表id
    private java.util.Date leaseBackDate; // 租赁交回时间
    private Long leaseId; // 租赁单位Id
    private String leaseUnit; // 租赁单位名称
    private java.math.BigDecimal alloAdjustNum; // 调拨调差额
    private java.math.BigDecimal originAdjustNum; // 原调差额
    private java.math.BigDecimal alloAmount; // 调拨额
    private java.math.BigDecimal originAmount; // 原金额
    private java.math.BigDecimal alloNum; // 调拨量
    private java.math.BigDecimal alloPrice; // 调拨价
    private java.math.BigDecimal storeNum; // 库存量
    private java.math.BigDecimal originPrice; // 原单价(入库单单价)
    private String eprjname; // 安全费用项目名称
    private String eprjid; // 安全费用项目id

    public String getEprjname() {
        return eprjname;
    }

    public void setEprjname(String eprjname) {
        this.eprjname = eprjname;
    }

    public String getEprjid() {
        return eprjid;
    }

    public void setEprjid(String eprjid) {
        this.eprjid = eprjid;
    }

    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getModel() {
        return model;
    }

    /**
     * 规格型号
     */
    public void setModel(String model) {
        this.model = model;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 单价/租赁单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价/租赁单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 申请数量/出库数量
     */
    public java.math.BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 申请数量/出库数量
     */
    public void setOutNum(java.math.BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getAmount() {
        return amount;
    }

    /**
     * 金额
     */
    public void setAmount(java.math.BigDecimal amount) {
        this.amount = amount;
    }
    /**
     * 调差额
     */
    public java.math.BigDecimal getAdjustNum() {
        return adjustNum;
    }

    /**
     * 调差额
     */
    public void setAdjustNum(java.math.BigDecimal adjustNum) {
        this.adjustNum = adjustNum;
    }
    /**
     * 用途
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用途
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 当前库存金额
     */
    public java.math.BigDecimal getNowStoreAmount() {
        return nowStoreAmount;
    }

    /**
     * 当前库存金额
     */
    public void setNowStoreAmount(java.math.BigDecimal nowStoreAmount) {
        this.nowStoreAmount = nowStoreAmount;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 主表id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 租赁交回时间
     */
    public java.util.Date getLeaseBackDate() {
        return leaseBackDate;
    }

    /**
     * 租赁交回时间
     */
    public void setLeaseBackDate(java.util.Date leaseBackDate) {
        this.leaseBackDate = leaseBackDate;
    }
    /**
     * 租赁单位Id
     */
    public Long getLeaseId() {
        return leaseId;
    }

    /**
     * 租赁单位Id
     */
    public void setLeaseId(Long leaseId) {
        this.leaseId = leaseId;
    }
    /**
     * 租赁单位名称
     */
    public String getLeaseUnit() {
        return leaseUnit;
    }

    /**
     * 租赁单位名称
     */
    public void setLeaseUnit(String leaseUnit) {
        this.leaseUnit = leaseUnit;
    }
    /**
     * 调拨调差额
     */
    public java.math.BigDecimal getAlloAdjustNum() {
        return alloAdjustNum;
    }

    /**
     * 调拨调差额
     */
    public void setAlloAdjustNum(java.math.BigDecimal alloAdjustNum) {
        this.alloAdjustNum = alloAdjustNum;
    }
    /**
     * 原调差额
     */
    public java.math.BigDecimal getOriginAdjustNum() {
        return originAdjustNum;
    }

    /**
     * 原调差额
     */
    public void setOriginAdjustNum(java.math.BigDecimal originAdjustNum) {
        this.originAdjustNum = originAdjustNum;
    }
    /**
     * 调拨额
     */
    public java.math.BigDecimal getAlloAmount() {
        return alloAmount;
    }

    /**
     * 调拨额
     */
    public void setAlloAmount(java.math.BigDecimal alloAmount) {
        this.alloAmount = alloAmount;
    }
    /**
     * 原金额
     */
    public java.math.BigDecimal getOriginAmount() {
        return originAmount;
    }

    /**
     * 原金额
     */
    public void setOriginAmount(java.math.BigDecimal originAmount) {
        this.originAmount = originAmount;
    }
    /**
     * 调拨量
     */
    public java.math.BigDecimal getAlloNum() {
        return alloNum;
    }

    /**
     * 调拨量
     */
    public void setAlloNum(java.math.BigDecimal alloNum) {
        this.alloNum = alloNum;
    }
    /**
     * 调拨价
     */
    public java.math.BigDecimal getAlloPrice() {
        return alloPrice;
    }

    /**
     * 调拨价
     */
    public void setAlloPrice(java.math.BigDecimal alloPrice) {
        this.alloPrice = alloPrice;
    }
    /**
     * 库存量
     */
    public java.math.BigDecimal getStoreNum() {
        return storeNum;
    }

    /**
     * 库存量
     */
    public void setStoreNum(java.math.BigDecimal storeNum) {
        this.storeNum = storeNum;
    }
    /**
     * 原单价(入库单单价)
     */
    public java.math.BigDecimal getOriginPrice() {
        return originPrice;
    }

    /**
     * 原单价(入库单单价)
     */
    public void setOriginPrice(java.math.BigDecimal originPrice) {
        this.originPrice = originPrice;
    }
    
}

==> ejc-sdbjmaterial-impl-3.0.0-20201028.094120-23-sources.jar: com/ejianc/integration/sdbjmaterial/vo/OutstoreDetailVO.java <==
package com.ejianc.integration.sdbjmaterial.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 领料出库子表
 * 
 * @author generator
 * 
 */
public class OutstoreDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String materialName; // 物资名称
    private String materialId; // 物资id
    private String model; // 规格型号
    private String unit; // 单位
    private java.math.BigDecimal price; // 单价/租赁单价
    private java.math.BigDecimal outNum; // 申请数量/出库数量
    private java.math.BigDecimal amount; // 金额
    private java.math.BigDecimal adjustNum; // 调差额
    private String useFor; // 用途
    private java.math.BigDecimal nowStoreAmount; // 当前库存金额
    private String memo; // 备注
    private Long pid; // 主表id
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date leaseBackDate; // 租赁交回时间
    private String leaseId; // 租赁单位Id
    private String leaseUnit; // 租赁单位名称
    private java.math.BigDecimal alloAdjustNum; // 调拨调差额
    private java.math.BigDecimal originAdjustNum; // 原调差额
    private java.math.BigDecimal alloAmount; // 调拨额
    private java.math.BigDecimal originAmount; // 原金额
    private java.math.BigDecimal alloNum; // 调拨量
    private java.math.BigDecimal alloPrice; // 调拨价
    private java.math.BigDecimal storeNum; // 库存量
    private java.math.BigDecimal originPrice; // 原单价(入库单单价)
    private String eprjname; // 安全费用项目名称
    private String eprjid; // 安全费用项目id
    private String hireunit; // 租赁单位

    public String getHireunit() {
        return hireunit;
    }

    public void setHireunit(String hireunit) {
        this.hireunit = hireunit;
    }

    public String getEprjname() {
        return eprjname;
    }

    public void setEprjname(String eprjname) {
        this.eprjname = eprjname;
    }

    public String getEprjid() {
        return eprjid;
    }

    public void setEprjid(String eprjid) {
        this.eprjid = eprjid;
    }

    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资id
     */
    public String getMaterialId() {
        return materialId;
    }

    /**
     * 物资id
     */
    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getModel() {
        return model;
    }

    /**
     * 规格型号
     */
    public void setModel(String model) {
        this.model = model;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 单价/租赁单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价/租赁单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 申请数量/出库数量
     */
    public java.math.BigDecimal getOutNum() {
        return outNum;
    }

    /**
     * 申请数量/出库数量
     */
    public void setOutNum(java.math.BigDecimal outNum) {
        this.outNum = outNum;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getAmount() {
        return amount;
    }

    /**
     * 金额
     */
    public void setAmount(java.math.BigDecimal amount) {
        this.amount = amount;
    }
    /**
     * 调差额
     */
    public java.math.BigDecimal getAdjustNum() {
        return adjustNum;
    }

    /**
     * 调差额
     */
    public void setAdjustNum(java.math.BigDecimal adjustNum) {
        this.adjustNum = adjustNum;
    }
    /**
     * 用途
     */
    public String getUseFor() {
        return useFor;
    }

    /**
     * 用途
     */
    public void setUseFor(String useFor) {
        this.useFor = useFor;
    }
    /**
     * 当前库存金额
     */
    public java.math.BigDecimal getNowStoreAmount() {
        return nowStoreAmount;
    }

    /**
     * 当前库存金额
     */
    public void setNowStoreAmount(java.math.BigDecimal nowStoreAmount) {
        this.nowStoreAmount = nowStoreAmount;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 主表id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 租赁交回时间
     */
    public java.util.Date getLeaseBackDate() {
        return leaseBackDate;
    }

    /**
     * 租赁交回时间
     */
    public void setLeaseBackDate(java.util.Date leaseBackDate) {
        this.leaseBackDate = leaseBackDate;
    }
    /**
     * 租赁单位Id
     */
    public String getLeaseId() {
        return leaseId;
    }

    /**
     * 租赁单位Id
     */
    public void setLeaseId(String leaseId) {
        this.leaseId = leaseId;
    }
    /**
     * 租赁单位名称
     */
    public String getLeaseUnit() {
        return leaseUnit;
    }

    /**
     * 租赁单位名称
     */
    public void setLeaseUnit(String leaseUnit) {
        this.leaseUnit = leaseUnit;
    }
    /**
     * 调拨调差额
     */
    public java.math.BigDecimal getAlloAdjustNum() {
        return alloAdjustNum;
    }

    /**
     * 调拨调差额
     */
    public void setAlloAdjustNum(java.math.BigDecimal alloAdjustNum) {
        this.alloAdjustNum = alloAdjustNum;
    }
    /**
     * 原调差额
     */
    public java.math.BigDecimal getOriginAdjustNum() {
        return originAdjustNum;
    }

    /**
     * 原调差额
     */
    public void setOriginAdjustNum(java.math.BigDecimal originAdjustNum) {
        this.originAdjustNum = originAdjustNum;
    }
    /**
     * 调拨额
     */
    public java.math.BigDecimal getAlloAmount() {
        return alloAmount;
    }

    /**
     * 调拨额
     */
    public void setAlloAmount(java.math.BigDecimal alloAmount) {
        this.alloAmount = alloAmount;
    }
    /**
     * 原金额
     */
    public java.math.BigDecimal getOriginAmount() {
        return originAmount;
    }

    /**
     * 原金额
     */
    public void setOriginAmount(java.math.BigDecimal originAmount) {
        this.originAmount = originAmount;
    }
    /**
     * 调拨量
     */
    public java.math.BigDecimal getAlloNum() {
        return alloNum;
    }

    /**
     * 调拨量
     */
    public void setAlloNum(java.math.BigDecimal alloNum) {
        this.alloNum = alloNum;
    }
    /**
     * 调拨价
     */
    public java.math.BigDecimal getAlloPrice() {
        return alloPrice;
    }

    /**
     * 调拨价
     */
    public void setAlloPrice(java.math.BigDecimal alloPrice) {
        this.alloPrice = alloPrice;
    }
    /**
     * 库存量
     */
    public java.math.BigDecimal getStoreNum() {
        return storeNum;
    }

    /**
     * 库存量
     */
    public void setStoreNum(java.math.BigDecimal storeNum) {
        this.storeNum = storeNum;
    }
    /**
     * 原单价(入库单单价)
     */
    public java.math.BigDecimal getOriginPrice() {
        return originPrice;
    }

    /**
     * 原单价(入库单单价)
     */
    public void setOriginPrice(java.math.BigDecimal originPrice) {
        this.originPrice = originPrice;
    }
    
}
